==> dde-daemon_3.2.13.3.orig.tar.xz: dde-daemon-3.2.13.3/misc/ts/com.deepin.daemon.accounts.policy/policy_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>Za spremembo lastnih podatkov je zahtevana overitev</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>Spremenite lastne uporabniške podatke</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>Za spremembo podatkov uporabnikov je zahtevana overitev</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>Upravljaj račune uporabnikov</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>Za omogočanje samodejne prijave je potrebna avtentikacija</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>Omogoči samodejno prijavo</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>Za onemogočanje samodejne prijave je potrebna avtentikacija</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>Onemogoči samodejno prijavo</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>Za prijavo brez gesla je potrebna avtentikacija</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>Omogoči prijavo brez gesla</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>Za onemogočanje prijave brez gesla je potrebna avtentikacija</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>Onemogoči prijavo brez gesla</translation>
		</message>
	</context>
</TS>

==> dde-daemon_5.12.52.orig.tar.xz: dde-daemon-5.12.52/misc/ts/com.deepin.daemon.accounts.policy/policy_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>Za spremembo lastnih podatkov je zahtevana overitev</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>Spremenite uporabniške podatke</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>Srememba podatkov uporabnika zahteva overitev</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>Upravljanje uporabniških računov</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>Vklop samodejne prijave zahteva overitev</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>Vklopi samodejno prijavo</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>Izklop samodejne prijave zahteva overitev</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>Izklopi samodejno prijavo</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>Prijava brez gesla zahteva overitev</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>Vklopi prijavo brez gesla</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>Izklop prijave brez gesla zahteva overitev</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>Izklopi prijavo brez gesla</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>Sprememba razporeda tipkovnice zahteva overitev</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>Določi razpored tipkovnice</translation>
		</message>
	</context>
</TS>
